==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/files_sharing/l10n/ru.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "На данном сервере выключено межсерверное предоставление общего доступа",
    "The mountpoint name contains invalid characters." : "Имя точки монтирования содержит недопустимые символы.",
    "Invalid or untrusted SSL certificate" : "Недействительный или недоверенный сертификат SSL",
    "Could not authenticate to remote share, password might be wrong" : "Не удалось произвести аутентификацию для доступа к удалённому хранилищу, возможно неправильно указан пароль",
    "Storage not valid" : "Хранилище недоступно",
    "Couldn't add remote share" : "Невозможно добавить удалённый общий ресурс",
    "Shared with you" : "Поделились с вами",
    "Shared with others" : "Доступные для других",
    "Shared by link" : "Доступные по ссылке",
    "Nothing shared with you yet" : "С вами пока ничем не поделились",
    "Files and folders others share with you will show up here" : "Здесь появятся файлы и каталоги, которыми с вами поделятся",
    "Nothing shared yet" : "Пока ничего не опубликовано",
    "Files and folders you share will show up here" : "Здесь появятся файлы и каталоги, которыми вы поделитесь",
    "No shared links" : "Нет общих ссылок",
    "Files and folders you share by link will show up here" : "Здесь появятся файлы и каталоги, ссылкой на которые вы поделитесь",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Добавить удалённую общую папку {name} из {owner}@{remote}?",
    "Remote share" : "Удаленный общий ресурс",
    "Remote share password" : "Пароль для удаленного общего ресурса",
    "Cancel" : "Отменить",
    "Add remote share" : "Добавить удалённый общий ресурс",
    "No ownCloud installation (7 or higher) found at {remote}" : "На удаленном ресурсе {remote} не установлен ownCloud версии 7 или выше",
    "Invalid ownCloud url" : "Неверный адрес ownCloud",
    "Share" : "Поделиться",
    "Shared by" : "Поделился",
    "A file or folder was shared from <strong>another server</strong>" : "Файлом или каталогом поделились с <strong>удаленного сервера</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Общий файл или каталог был <strong>скачан</strong>",
    "You received a new remote share from %s" : "%s поделился с вами удаленным общим ресурсом",
    "%1$s accepted remote share %2$s" : "%1$s принял удаленный общий ресурс %2$s",
    "%1$s declined remote share %2$s" : "%1$s отклонил удаленный общий ресурс %2$s",
    "%1$s unshared %2$s from you" : "%1$s закрыл для вас доступ к %2$s ",
    "Public shared folder %1$s was downloaded" : "Общий каталог %1$s был скачан",
    "Public shared file %1$s was downloaded" : "Общий файл %1$s, был скачан",
    "This share is password-protected" : "Общий ресурс защищен паролем",
    "The password is wrong. Try again." : "Неверный пароль. Попробуйте еще раз.",
    "Password" : "Пароль",
    "No entries found in this folder" : "Нет элементов в этом каталоге",
    "Name" : "Имя",
    "Share time" : "Дата публикации",
    "Sorry, this link doesn’t seem to work anymore." : "Эта ссылка устарела и более не действительна.",
    "Reasons might be:" : "Причиной может быть:",
    "the item was removed" : "элемент был удалён",
    "the link expired" : "срок действия ссылки истёк",
    "sharing is disabled" : "общий доступ отключён",
    "For more info, please ask the person who sent this link." : "Для получения дополнительной информации, свяжитесь с тем, кто отправил вам эту ссылку.",
    "Add to your ownCloud" : "Добавить в свой ownCloud",
    "Download" : "Скачать",
    "Download %s" : "Скачать %s",
    "Direct link" : "Прямая ссылка",
    "Federated Cloud Sharing" : "Объединение облачных хранилищ",
    "Allow users on this server to send shares to other servers" : "Разрешить пользователям делиться с пользователями других серверов",
    "Allow users on this server to receive shares from other servers" : "Разрешить пользователям использовать общие ресурсы с других серверов"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files_sharing/l10n/ru.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "На данном сервере выключено межсерверное предоставление общего доступа",
    "The mountpoint name contains invalid characters." : "Имя точки монтирования содержит недопустимые символы.",
    "Invalid or untrusted SSL certificate" : "Недействительный или недоверенный сертификат SSL",
    "Could not authenticate to remote share, password might be wrong" : "Не удалось произвести аутентификацию для доступа к удалённому хранилищу, возможно неправильно указан пароль",
    "Storage not valid" : "Хранилище недоступно",
    "Couldn't add remote share" : "Невозможно добавить удалённый общий ресурс",
    "Shared with you" : "Поделились с вами",
    "Shared with others" : "Доступные для других",
    "Shared by link" : "Доступные по ссылке",
    "Nothing shared with you yet" : "С вами пока ничем не поделились",
    "Files and folders others share with you will show up here" : "Здесь появятся файлы и каталоги, которыми с вами поделятся",
    "Nothing shared yet" : "Пока ничего не опубликовано",
    "Files and folders you share will show up here" : "Здесь появятся файлы и каталоги, которыми вы поделитесь",
    "No shared links" : "Нет общих ссылок",
    "Files and folders you share by link will show up here" : "Здесь появятся файлы и каталоги, ссылкой на которые вы поделитесь",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Добавить удалённую общую папку {name} из {owner}@{remote}?",
    "Remote share" : "Удаленный общий ресурс",
    "Remote share password" : "Пароль для удаленного общего ресурса",
    "Cancel" : "Отменить",
    "Add remote share" : "Добавить удалённый общий ресурс",
    "You can upload into this folder" : "Вы можете загружать в эту папку",
    "No ownCloud installation (7 or higher) found at {remote}" : "На удаленном ресурсе {remote} не установлен ownCloud версии 7 или выше",
    "Invalid ownCloud url" : "Неверный адрес ownCloud",
    "Share" : "Поделиться",
    "Shared by" : "Поделился",
    "A file or folder has been <strong>shared</strong>" : "<strong>Опубликован</strong> файл или каталог",
    "A file or folder was shared from <strong>another server</strong>" : "Файлом или каталогом поделились с <strong>удаленного сервера</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Общий файл или каталог был <strong>скачан</strong>",
    "You received a new remote share from %s" : "%s поделился с вами удаленным общим ресурсом",
    "%1$s accepted remote share %2$s" : "%1$s принял удаленный общий ресурс %2$s",
    "%1$s declined remote share %2$s" : "%1$s отклонил удаленный общий ресурс %2$s",
    "%1$s unshared %2$s from you" : "%1$s закрыл для вас доступ к %2$s ",
    "Public shared folder %1$s was downloaded" : "Общий каталог %1$s был скачан",
    "Public shared file %1$s was downloaded" : "Общий файл %1$s, был скачан",
    "You shared %1$s with %2$s" : "Вы поделились %1$s с %2$s",
    "You shared %1$s with group %2$s" : "Вы поделились %1$s с группой %2$s",
    "%2$s shared %1$s with you" : "%2$s поделился с вами %1$s",
    "You shared %1$s via link" : "Вы поделились %1$s с помощью ссылки",
    "Shares" : "События обмена файлами",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Поделитесь со мной через мой #ownCloud ID в объединении облачных хранилищ, смотрите %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Поделитесь со мной через мой #ownCloud ID в объединении облачных хранилищ",
    "This share is password-protected" : "Общий ресурс защищен паролем",
    "The password is wrong. Try again." : "Неверный пароль. Попробуйте еще раз.",
    "Password" : "Пароль",
    "No entries found in this folder" : "Нет элементов в этом каталоге",
    "Name" : "Имя",
    "Share time" : "Дата публикации",
    "Sorry, this link doesn’t seem to work anymore." : "Эта ссылка устарела и более не действительна.",
    "Reasons might be:" : "Причиной может быть:",
    "the item was removed" : "элемент был удалён",
    "the link expired" : "срок действия ссылки истёк",
    "sharing is disabled" : "общий доступ отключён",
    "For more info, please ask the person who sent this link." : "Для получения дополнительной информации, свяжитесь с тем, кто отправил вам эту ссылку.",
    "Add to your ownCloud" : "Добавить в свой ownCloud",
    "Download" : "Скачать",
    "Download %s" : "Скачать %s",
    "Direct link" : "Прямая ссылка",
    "Federated Cloud Sharing" : "Объединение облачных хранилищ",
    "Open documentation" : "Открыть документацию",
    "Allow users on this server to send shares to other servers" : "Разрешить пользователям делиться с пользователями других серверов",
    "Allow users on this server to receive shares from other servers" : "Разрешить пользователям использовать общие ресурсы с других серверов",
    "Federated Cloud" : "Объединение облачных хранилищ",
    "Your Federated Cloud ID:" : "Ваш ID в объединении облачных хранилищ:",
    "Share it:" : "Поделись этим:",
    "Add it to your website:" : "Добавь это на свой сайт:",
    "Share with me via ownCloud" : "Поделитесь мной через ownCloud",
    "HTML Code:" : "HTML код:"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
